CliCommand

Enum CliCommand 

pub enum CliCommand {
Show 14 variants Faker { count: u64, }, Fetch { uri: String, save: bool, fetch_as: Option<String>, }, Relay { action: RelayCommand, }, Count { likes: bool, shares: bool, replies: bool, }, Update { days: i64, limit: Option<u64>, }, Register { username: String, password: String, display_name: Option<String>, summary: Option<String>, avatar_url: Option<String>, banner_url: Option<String>, }, Reset { login: String, password: String, }, Nuke { for_real: bool, delete_objects: bool, }, Thread {}, Cloak { objects: bool, actors: bool, contents: bool, re_cloak: bool, }, FixActivities { likes: bool, announces: bool, }, Import { file: PathBuf, from: String, to: String, attachment_base: Option<String>, }, Export { actor: String, file: PathBuf, pretty: bool, }, Attachments {},
}

Variants



Faker

generate fake user, note and activity

Fields

count: u64

how many fake statuses to insert for root user



Fetch

fetch a single AP object

Fields

uri: String

object id, or uri, to fetch

save: bool

store fetched object in local db

fetch_as: Option<String>

use this actor’s private key to fetch



Relay

act on remote relay actors at instance level

Fields

action: RelayCommand

action to take against this relay



Count

recount object statistics

Fields

likes: bool

fix likes counts for posts

shares: bool

fix shares counts for posts

replies: bool

fix replies counts for posts



Update

update remote actors

Fields

days: i64

number of days after which actors should get updated

limit: Option<u64>

stop after updating this many actors



Register

register a new local user

Fields

username: String

username for new user, must be unique locally and cannot be changed

password: String

password for new user

display_name: Option<String>

display name for new user

summary: Option<String>

summary text for new user

avatar_url: Option<String>

url for avatar image of new user

banner_url: Option<String>

url for banner image of new user



Reset

reset password of a user

Fields

login: String

user login

password: String

new password



Nuke

break all user relations so that instance can be shut down

Fields

for_real: bool

unless this is set, nuke will be a dry run

delete_objects: bool

also send Delete activities for all local objects



Thread

attempt to fix broken threads and completely gather their context



Cloak

replaces all attachment urls with proxied local versions (only useful for old instances)

Fields

objects: bool

also cloak objects image urls

actors: bool

also cloak actor images

contents: bool

also replace urls inside post contents

re_cloak: bool

also re-cloak already cloaked urls, useful if changing cloak secret



FixActivities

restore activities links, only needed for very old installs

Fields

likes: bool

restore like activity links

announces: bool

restore announces activity links



Import

import posts coming from another instance: replay them as local

Fields

file: PathBuf

json backup file: must be an array of objects

from: String

previous actor id, used in these posts

to: String

current actor id, will be replaced in all posts

attachment_base: Option<String>

base url where attachments are hosted now, if not given attachments will be kept unchanged



Export

export posts from a local actor as a json array, like an outbox

Fields

actor: String

local username of actor to export

file: PathBuf

json backup file: will be an array of objects

pretty: bool

serialize json in human-readable form



Attachments

fix attachments types based on mediaType