pub enum RelayCommand {
Status,
Follow {
actor: String,
},
Accept {
actor: String,
},
Unfollow {
actor: String,
},
Remove {
actor: String,
},
}Expand description
available actions to take on relays
Variants
Status
get all current pending and accepted relays
Follow
request to follow a specific relay
Accept
accept a pending relay request
Unfollow
retract a follow relation to a relay, stopping receiving content
Remove
remove a follow relation from a relay, stopping sending content