pub enum CliCommand {
Show 14 variants
Faker {
count: u64,
},
Fetch {
uri: String,
save: bool,
fetch_as: Option<String>,
},
Relay {
action: RelayCommand,
},
Count {
likes: bool,
shares: bool,
replies: bool,
},
Update {
days: i64,
limit: Option<u64>,
},
Register {
username: String,
password: String,
display_name: Option<String>,
summary: Option<String>,
avatar_url: Option<String>,
banner_url: Option<String>,
},
Reset {
login: String,
password: String,
},
Nuke {
for_real: bool,
delete_objects: bool,
},
Thread {},
Cloak {
objects: bool,
actors: bool,
contents: bool,
re_cloak: bool,
},
FixActivities {
likes: bool,
announces: bool,
},
Import {
file: PathBuf,
from: String,
to: String,
attachment_base: Option<String>,
},
Export {
actor: String,
file: PathBuf,
pretty: bool,
},
Attachments {},
}Variants
Faker
generate fake user, note and activity
Fetch
fetch a single AP object
Fields
Relay
act on remote relay actors at instance level
Fields

action: RelayCommandaction to take against this relay
Count
recount object statistics
Fields
fix shares counts for posts
Update
update remote actors
Fields
Register
register a new local user
Fields
url for banner image of new user
Reset
reset password of a user
Nuke
break all user relations so that instance can be shut down
Fields
Thread
attempt to fix broken threads and completely gather their context
Cloak
replaces all attachment urls with proxied local versions (only useful for old instances)
Fields
FixActivities
restore activities links, only needed for very old installs
Import
import posts coming from another instance: replay them as local
Fields
Export
export posts from a local actor as a json array, like an outbox
Fields
Attachments
fix attachments types based on mediaType